# Contributing to FAISSx

First off, thank you for considering contributing to FAISSx! It's people like you that make FAISSx such a great tool.

## How Can I Contribute?

### Reporting Bugs

This section guides you through submitting a bug report for FAISSx. Following these guidelines helps maintainers and the community understand your report, reproduce the behavior, and find related reports.

**Before Submitting A Bug Report:**
- Check the [issues](https://github.com/muxi-ai/faissx/issues) for a list of current known issues.
- Perform a [search](https://github.com/muxi-ai/faissx/issues?q=is%3Aissue) to see if the problem has already been reported.

**How Do I Submit A Good Bug Report?**
- Use a clear and descriptive title for the issue to identify the problem.
- Describe the exact steps which reproduce the problem in as many details as possible.
- Provide specific examples to demonstrate the steps.
- Describe the behavior you observed after following the steps and point out what exactly is the problem with that behavior.
- Explain which behavior you expected to see instead and why.
- Include screenshots or animated GIFs if possible.

### Suggesting Enhancements

This section guides you through submitting an enhancement suggestion for FAISSx, including completely new features and minor improvements to existing functionality.

**Before Submitting An Enhancement Suggestion:**
- Check if the enhancement has already been suggested or implemented.
- Determine which repository the enhancement should be suggested in.

**How Do I Submit A Good Enhancement Suggestion?**
- Use a clear and descriptive title for the issue to identify the suggestion.
- Provide a step-by-step description of the suggested enhancement in as many details as possible.
- Provide specific examples to demonstrate the steps or point out the part of FAISSx which the enhancement will affect.
- Describe the current behavior and explain which behavior you expected to see instead and why.
- Explain why this enhancement would be useful to most FAISSx users.

### Pull Requests

- Fill in the required template
- Do not include issue numbers in the PR title
- Follow the Python style guide
- Document new code
- Run tests locally before submitting
- Write or update tests as needed

## Styleguides

### Git Commit Messages

- Use the present tense ("Add feature" not "Added feature")
- Use the imperative mood ("Move cursor to..." not "Moves cursor to...")
- Limit the first line to 72 characters or less
- Reference issues and pull requests liberally after the first line

### Python Styleguide

- Follow [PEP 8](https://www.python.org/dev/peps/pep-0008/)
- Use 4 spaces for indentation
- Add docstrings to all modules, functions, classes, and methods
- Run `flake8` before submitting

### Documentation Styleguide

- Use [Markdown](https://daringfireball.net/projects/markdown/) for documentation.
- Follow the [Google Python Style Guide](https://google.github.io/styleguide/pyguide.html#38-comments-and-docstrings) for docstrings.

## Additional Notes

### Issue and Pull Request Labels

This section lists the labels we use to help us track and manage issues and pull requests.

* **bug** - Issues for bugs in the code
* **documentation** - Issues for improving or updating documentation
* **enhancement** - Issues for new features or improvements
* **help-wanted** - Issues where we need assistance
* **question** - Issues that are questions or need more information
* **good-first-issue** - Good for newcomers

## Acknowledgments

This CONTRIBUTING.md was adapted from various open-source projects.

Thank you for contributing to FAISSx!
